Managing Resources
==================

Resources in LinchPin generally consist of Virtual Machines, Containers, Networks, Security Groups, Instances, and much more. Detailed below are examples of topoologies, layouts, and PinFiles used to manage resources.

.. toctree::
   :tocdepth: 1

.. _res_pinfiles:

PinFiles
--------

.. include:: resources/pinfiles.rst

.. _res_topologies:

Topologies
----------

.. include:: resources/topologies.rst

.. _res_layouts:

Layouts
-------

.. include:: resources/layouts.rst

.. seealso::

    :doc:`providers`

